Class: Aws::MailManager::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MailManager::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mailmanager/client.rb,
sig/client.rbs
Overview
An API client for MailManager. To construct a client, you need to configure a :region and :credentials.
client = Aws::MailManager::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAddonInstanceResponseSuccess, _CreateAddonSubscriptionResponseSuccess, _CreateAddressListImportJobResponseSuccess, _CreateAddressListResponseSuccess, _CreateArchiveResponseSuccess, _CreateIngressPointResponseSuccess, _CreateRelayResponseSuccess, _CreateRuleSetResponseSuccess, _CreateTrafficPolicyResponseSuccess, _DeleteAddonInstanceResponseSuccess, _DeleteAddonSubscriptionResponseSuccess, _DeleteAddressListResponseSuccess, _DeleteArchiveResponseSuccess, _DeleteIngressPointResponseSuccess, _DeleteRelayResponseSuccess, _DeleteRuleSetResponseSuccess, _DeleteTrafficPolicyResponseSuccess, _DeregisterMemberFromAddressListResponseSuccess, _GetAddonInstanceResponseSuccess, _GetAddonSubscriptionResponseSuccess, _GetAddressListImportJobResponseSuccess, _GetAddressListResponseSuccess, _GetArchiveExportResponseSuccess, _GetArchiveMessageContentResponseSuccess, _GetArchiveMessageResponseSuccess, _GetArchiveResponseSuccess, _GetArchiveSearchResponseSuccess, _GetArchiveSearchResultsResponseSuccess, _GetIngressPointResponseSuccess, _GetMemberOfAddressListResponseSuccess, _GetRelayResponseSuccess, _GetRuleSetResponseSuccess, _GetTrafficPolicyResponseSuccess, _ListAddonInstancesResponseSuccess, _ListAddonSubscriptionsResponseSuccess, _ListAddressListImportJobsResponseSuccess, _ListAddressListsResponseSuccess, _ListArchiveExportsResponseSuccess, _ListArchiveSearchesResponseSuccess, _ListArchivesResponseSuccess, _ListIngressPointsResponseSuccess, _ListMembersOfAddressListResponseSuccess, _ListRelaysResponseSuccess, _ListRuleSetsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTrafficPoliciesResponseSuccess, _RegisterMemberToAddressListResponseSuccess, _StartAddressListImportJobResponseSuccess, _StartArchiveExportResponseSuccess, _StartArchiveSearchResponseSuccess, _StopAddressListImportJobResponseSuccess, _StopArchiveExportResponseSuccess, _StopArchiveSearchResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateArchiveResponseSuccess, _UpdateIngressPointResponseSuccess, _UpdateRelayResponseSuccess, _UpdateRuleSetResponseSuccess, _UpdateTrafficPolicyResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_addon_instance(params = {}) ⇒ Types::CreateAddonInstanceResponse
Creates an Add On instance for the subscription indicated in the request.
-
#create_addon_subscription(params = {}) ⇒ Types::CreateAddonSubscriptionResponse
Creates a subscription for an Add On representing the acceptance of its terms of use and additional pricing.
-
#create_address_list(params = {}) ⇒ Types::CreateAddressListResponse
Creates a new address list.
-
#create_address_list_import_job(params = {}) ⇒ Types::CreateAddressListImportJobResponse
Creates an import job for an address list.
-
#create_archive(params = {}) ⇒ Types::CreateArchiveResponse
Creates a new email archive resource for storing and retaining emails.
-
#create_ingress_point(params = {}) ⇒ Types::CreateIngressPointResponse
Provision a new ingress endpoint resource.
-
#create_relay(params = {}) ⇒ Types::CreateRelayResponse
Creates a relay resource which can be used in rules to relay incoming emails to defined relay destinations.
-
#create_rule_set(params = {}) ⇒ Types::CreateRuleSetResponse
Provision a new rule set.
-
#create_traffic_policy(params = {}) ⇒ Types::CreateTrafficPolicyResponse
Provision a new traffic policy resource.
-
#delete_addon_instance(params = {}) ⇒ Struct
Deletes an Add On instance.
-
#delete_addon_subscription(params = {}) ⇒ Struct
Deletes an Add On subscription.
-
#delete_address_list(params = {}) ⇒ Struct
Deletes an address list.
-
#delete_archive(params = {}) ⇒ Struct
Initiates deletion of an email archive.
-
#delete_ingress_point(params = {}) ⇒ Struct
Delete an ingress endpoint resource.
-
#delete_relay(params = {}) ⇒ Struct
Deletes an existing relay resource.
-
#delete_rule_set(params = {}) ⇒ Struct
Delete a rule set.
-
#delete_traffic_policy(params = {}) ⇒ Struct
Delete a traffic policy resource.
-
#deregister_member_from_address_list(params = {}) ⇒ Struct
Removes a member from an address list.
-
#get_addon_instance(params = {}) ⇒ Types::GetAddonInstanceResponse
Gets detailed information about an Add On instance.
-
#get_addon_subscription(params = {}) ⇒ Types::GetAddonSubscriptionResponse
Gets detailed information about an Add On subscription.
-
#get_address_list(params = {}) ⇒ Types::GetAddressListResponse
Fetch attributes of an address list.
-
#get_address_list_import_job(params = {}) ⇒ Types::GetAddressListImportJobResponse
Fetch attributes of an import job.
-
#get_archive(params = {}) ⇒ Types::GetArchiveResponse
Retrieves the full details and current state of a specified email archive.
-
#get_archive_export(params = {}) ⇒ Types::GetArchiveExportResponse
Retrieves the details and current status of a specific email archive export job.
-
#get_archive_message(params = {}) ⇒ Types::GetArchiveMessageResponse
Returns a pre-signed URL that provides temporary download access to the specific email message stored in the archive.
-
#get_archive_message_content(params = {}) ⇒ Types::GetArchiveMessageContentResponse
Returns the textual content of a specific email message stored in the archive.
-
#get_archive_search(params = {}) ⇒ Types::GetArchiveSearchResponse
Retrieves the details and current status of a specific email archive search job.
-
#get_archive_search_results(params = {}) ⇒ Types::GetArchiveSearchResultsResponse
Returns the results of a completed email archive search job.
-
#get_ingress_point(params = {}) ⇒ Types::GetIngressPointResponse
Fetch ingress endpoint resource attributes.
-
#get_member_of_address_list(params = {}) ⇒ Types::GetMemberOfAddressListResponse
Fetch attributes of a member in an address list.
-
#get_relay(params = {}) ⇒ Types::GetRelayResponse
Fetch the relay resource and it's attributes.
-
#get_rule_set(params = {}) ⇒ Types::GetRuleSetResponse
Fetch attributes of a rule set.
-
#get_traffic_policy(params = {}) ⇒ Types::GetTrafficPolicyResponse
Fetch attributes of a traffic policy resource.
-
#list_addon_instances(params = {}) ⇒ Types::ListAddonInstancesResponse
Lists all Add On instances in your account.
-
#list_addon_subscriptions(params = {}) ⇒ Types::ListAddonSubscriptionsResponse
Lists all Add On subscriptions in your account.
-
#list_address_list_import_jobs(params = {}) ⇒ Types::ListAddressListImportJobsResponse
Lists jobs for an address list.
-
#list_address_lists(params = {}) ⇒ Types::ListAddressListsResponse
Lists address lists for this account.
-
#list_archive_exports(params = {}) ⇒ Types::ListArchiveExportsResponse
Returns a list of email archive export jobs.
-
#list_archive_searches(params = {}) ⇒ Types::ListArchiveSearchesResponse
Returns a list of email archive search jobs.
-
#list_archives(params = {}) ⇒ Types::ListArchivesResponse
Returns a list of all email archives in your account.
-
#list_ingress_points(params = {}) ⇒ Types::ListIngressPointsResponse
List all ingress endpoint resources.
-
#list_members_of_address_list(params = {}) ⇒ Types::ListMembersOfAddressListResponse
Lists members of an address list.
-
#list_relays(params = {}) ⇒ Types::ListRelaysResponse
Lists all the existing relay resources.
-
#list_rule_sets(params = {}) ⇒ Types::ListRuleSetsResponse
List rule sets for this account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags (keys and values) assigned to the resource.
-
#list_traffic_policies(params = {}) ⇒ Types::ListTrafficPoliciesResponse
List traffic policy resources.
-
#register_member_to_address_list(params = {}) ⇒ Struct
Adds a member to an address list.
-
#start_address_list_import_job(params = {}) ⇒ Struct
Starts an import job for an address list.
-
#start_archive_export(params = {}) ⇒ Types::StartArchiveExportResponse
Initiates an export of emails from the specified archive.
-
#start_archive_search(params = {}) ⇒ Types::StartArchiveSearchResponse
Initiates a search across emails in the specified archive.
-
#stop_address_list_import_job(params = {}) ⇒ Struct
Stops an ongoing import job for an address list.
-
#stop_archive_export(params = {}) ⇒ Struct
Stops an in-progress export of emails from an archive.
-
#stop_archive_search(params = {}) ⇒ Struct
Stops an in-progress archive search job.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags (keys and values) to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove one or more tags (keys and values) from a specified resource.
-
#update_archive(params = {}) ⇒ Struct
Updates the attributes of an existing email archive.
-
#update_ingress_point(params = {}) ⇒ Struct
Update attributes of a provisioned ingress endpoint resource.
-
#update_relay(params = {}) ⇒ Struct
Updates the attributes of an existing relay resource.
-
#update_rule_set(params = {}) ⇒ Struct
Update attributes of an already provisioned rule set.
-
#update_traffic_policy(params = {}) ⇒ Struct
Update attributes of an already provisioned traffic policy resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-mailmanager/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4056 4057 4058 |
# File 'lib/aws-sdk-mailmanager/client.rb', line 4056 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4059 4060 4061 |
# File 'lib/aws-sdk-mailmanager/client.rb', line 4059 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 |
# File 'lib/aws-sdk-mailmanager/client.rb', line 4029 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MailManager') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mailmanager' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#create_addon_instance(params = {}) ⇒ Types::CreateAddonInstanceResponse
Creates an Add On instance for the subscription indicated in the request. The resulting Amazon Resource Name (ARN) can be used in a conditional statement for a rule set or traffic policy.
87 |
# File 'sig/client.rbs', line 87
def create_addon_instance: (
|
#create_addon_subscription(params = {}) ⇒ Types::CreateAddonSubscriptionResponse
Creates a subscription for an Add On representing the acceptance of its terms of use and additional pricing. The subscription can then be used to create an instance for use in rule sets or traffic policies.
104 |
# File 'sig/client.rbs', line 104
def create_addon_subscription: (
|
#create_address_list(params = {}) ⇒ Types::CreateAddressListResponse
Creates a new address list.
121 |
# File 'sig/client.rbs', line 121
def create_address_list: (
|
#create_address_list_import_job(params = {}) ⇒ Types::CreateAddressListImportJobResponse
Creates an import job for an address list.
139 |
# File 'sig/client.rbs', line 139
def create_address_list_import_job: (
|
#create_archive(params = {}) ⇒ Types::CreateArchiveResponse
Creates a new email archive resource for storing and retaining emails.
154 |
# File 'sig/client.rbs', line 154
def create_archive: (
|
#create_ingress_point(params = {}) ⇒ Types::CreateIngressPointResponse
Provision a new ingress endpoint resource.
175 |
# File 'sig/client.rbs', line 175
def create_ingress_point: (
|
#create_relay(params = {}) ⇒ Types::CreateRelayResponse
Creates a relay resource which can be used in rules to relay incoming emails to defined relay destinations.
205 |
# File 'sig/client.rbs', line 205
def create_relay: (
|
#create_rule_set(params = {}) ⇒ Types::CreateRuleSetResponse
Provision a new rule set.
229 |
# File 'sig/client.rbs', line 229
def create_rule_set: (
|
#create_traffic_policy(params = {}) ⇒ Types::CreateTrafficPolicyResponse
Provision a new traffic policy resource.
249 |
# File 'sig/client.rbs', line 249
def create_traffic_policy: (
|
#delete_addon_instance(params = {}) ⇒ Struct
Deletes an Add On instance.
270 |
# File 'sig/client.rbs', line 270
def delete_addon_instance: (
|
#delete_addon_subscription(params = {}) ⇒ Struct
Deletes an Add On subscription.
279 |
# File 'sig/client.rbs', line 279
def delete_addon_subscription: (
|
#delete_address_list(params = {}) ⇒ Struct
Deletes an address list.
288 |
# File 'sig/client.rbs', line 288
def delete_address_list: (
|
#delete_archive(params = {}) ⇒ Struct
Initiates deletion of an email archive. This changes the archive state to pending deletion. In this state, no new emails can be added, and existing archived emails become inaccessible (search, export, download). The archive and all of its contents will be permanently deleted 30 days after entering the pending deletion state, regardless of the configured retention period.
297 |
# File 'sig/client.rbs', line 297
def delete_archive: (
|
#delete_ingress_point(params = {}) ⇒ Struct
Delete an ingress endpoint resource.
306 |
# File 'sig/client.rbs', line 306
def delete_ingress_point: (
|
#delete_relay(params = {}) ⇒ Struct
Deletes an existing relay resource.
315 |
# File 'sig/client.rbs', line 315
def delete_relay: (
|
#delete_rule_set(params = {}) ⇒ Struct
Delete a rule set.
324 |
# File 'sig/client.rbs', line 324
def delete_rule_set: (
|
#delete_traffic_policy(params = {}) ⇒ Struct
Delete a traffic policy resource.
333 |
# File 'sig/client.rbs', line 333
def delete_traffic_policy: (
|
#deregister_member_from_address_list(params = {}) ⇒ Struct
Removes a member from an address list.
342 |
# File 'sig/client.rbs', line 342
def deregister_member_from_address_list: (
|
#get_addon_instance(params = {}) ⇒ Types::GetAddonInstanceResponse
Gets detailed information about an Add On instance.
356 |
# File 'sig/client.rbs', line 356
def get_addon_instance: (
|
#get_addon_subscription(params = {}) ⇒ Types::GetAddonSubscriptionResponse
Gets detailed information about an Add On subscription.
368 |
# File 'sig/client.rbs', line 368
def get_addon_subscription: (
|
#get_address_list(params = {}) ⇒ Types::GetAddressListResponse
Fetch attributes of an address list.
382 |
# File 'sig/client.rbs', line 382
def get_address_list: (
|
#get_address_list_import_job(params = {}) ⇒ Types::GetAddressListImportJobResponse
Fetch attributes of an import job.
402 |
# File 'sig/client.rbs', line 402
def get_address_list_import_job: (
|
#get_archive(params = {}) ⇒ Types::GetArchiveResponse
Retrieves the full details and current state of a specified email archive.
419 |
# File 'sig/client.rbs', line 419
def get_archive: (
|
#get_archive_export(params = {}) ⇒ Types::GetArchiveExportResponse
Retrieves the details and current status of a specific email archive export job.
435 |
# File 'sig/client.rbs', line 435
def get_archive_export: (
|
#get_archive_message(params = {}) ⇒ Types::GetArchiveMessageResponse
Returns a pre-signed URL that provides temporary download access to the specific email message stored in the archive.
447 |
# File 'sig/client.rbs', line 447
def get_archive_message: (
|
#get_archive_message_content(params = {}) ⇒ Types::GetArchiveMessageContentResponse
Returns the textual content of a specific email message stored in the archive. Attachments are not included.
457 |
# File 'sig/client.rbs', line 457
def get_archive_message_content: (
|
#get_archive_search(params = {}) ⇒ Types::GetArchiveSearchResponse
Retrieves the details and current status of a specific email archive search job.
472 |
# File 'sig/client.rbs', line 472
def get_archive_search: (
|
#get_archive_search_results(params = {}) ⇒ Types::GetArchiveSearchResultsResponse
Returns the results of a completed email archive search job.
482 |
# File 'sig/client.rbs', line 482
def get_archive_search_results: (
|
#get_ingress_point(params = {}) ⇒ Types::GetIngressPointResponse
Fetch ingress endpoint resource attributes.
504 |
# File 'sig/client.rbs', line 504
def get_ingress_point: (
|
#get_member_of_address_list(params = {}) ⇒ Types::GetMemberOfAddressListResponse
Fetch attributes of a member in an address list.
516 |
# File 'sig/client.rbs', line 516
def get_member_of_address_list: (
|
#get_relay(params = {}) ⇒ Types::GetRelayResponse
Fetch the relay resource and it's attributes.
534 |
# File 'sig/client.rbs', line 534
def get_relay: (
|
#get_rule_set(params = {}) ⇒ Types::GetRuleSetResponse
Fetch attributes of a rule set.
549 |
# File 'sig/client.rbs', line 549
def get_rule_set: (
|
#get_traffic_policy(params = {}) ⇒ Types::GetTrafficPolicyResponse
Fetch attributes of a traffic policy resource.
566 |
# File 'sig/client.rbs', line 566
def get_traffic_policy: (
|
#list_addon_instances(params = {}) ⇒ Types::ListAddonInstancesResponse
Lists all Add On instances in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
577 |
# File 'sig/client.rbs', line 577
def list_addon_instances: (
|
#list_addon_subscriptions(params = {}) ⇒ Types::ListAddonSubscriptionsResponse
Lists all Add On subscriptions in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
589 |
# File 'sig/client.rbs', line 589
def list_addon_subscriptions: (
|
#list_address_list_import_jobs(params = {}) ⇒ Types::ListAddressListImportJobsResponse
Lists jobs for an address list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
601 |
# File 'sig/client.rbs', line 601
def list_address_list_import_jobs: (
|
#list_address_lists(params = {}) ⇒ Types::ListAddressListsResponse
Lists address lists for this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
614 |
# File 'sig/client.rbs', line 614
def list_address_lists: (
|
#list_archive_exports(params = {}) ⇒ Types::ListArchiveExportsResponse
Returns a list of email archive export jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
626 |
# File 'sig/client.rbs', line 626
def list_archive_exports: (
|
#list_archive_searches(params = {}) ⇒ Types::ListArchiveSearchesResponse
Returns a list of email archive search jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
639 |
# File 'sig/client.rbs', line 639
def list_archive_searches: (
|
#list_archives(params = {}) ⇒ Types::ListArchivesResponse
Returns a list of all email archives in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
652 |
# File 'sig/client.rbs', line 652
def list_archives: (
|
#list_ingress_points(params = {}) ⇒ Types::ListIngressPointsResponse
List all ingress endpoint resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
664 |
# File 'sig/client.rbs', line 664
def list_ingress_points: (
|
#list_members_of_address_list(params = {}) ⇒ Types::ListMembersOfAddressListResponse
Lists members of an address list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
676 |
# File 'sig/client.rbs', line 676
def list_members_of_address_list: (
|
#list_relays(params = {}) ⇒ Types::ListRelaysResponse
Lists all the existing relay resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
692 |
# File 'sig/client.rbs', line 692
def list_relays: (
|
#list_rule_sets(params = {}) ⇒ Types::ListRuleSetsResponse
List rule sets for this account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
704 |
# File 'sig/client.rbs', line 704
def list_rule_sets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags (keys and values) assigned to the resource.
715 |
# File 'sig/client.rbs', line 715
def list_tags_for_resource: (
|
#list_traffic_policies(params = {}) ⇒ Types::ListTrafficPoliciesResponse
List traffic policy resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
726 |
# File 'sig/client.rbs', line 726
def list_traffic_policies: (
|
#register_member_to_address_list(params = {}) ⇒ Struct
Adds a member to an address list.
736 |
# File 'sig/client.rbs', line 736
def register_member_to_address_list: (
|
#start_address_list_import_job(params = {}) ⇒ Struct
Starts an import job for an address list.
746 |
# File 'sig/client.rbs', line 746
def start_address_list_import_job: (
|
#start_archive_export(params = {}) ⇒ Types::StartArchiveExportResponse
Initiates an export of emails from the specified archive.
756 |
# File 'sig/client.rbs', line 756
def start_archive_export: (
|
#start_archive_search(params = {}) ⇒ Types::StartArchiveSearchResponse
Initiates a search across emails in the specified archive.
776 |
# File 'sig/client.rbs', line 776
def start_archive_search: (
|
#stop_address_list_import_job(params = {}) ⇒ Struct
Stops an ongoing import job for an address list.
789 |
# File 'sig/client.rbs', line 789
def stop_address_list_import_job: (
|
#stop_archive_export(params = {}) ⇒ Struct
Stops an in-progress export of emails from an archive.
798 |
# File 'sig/client.rbs', line 798
def stop_archive_export: (
|
#stop_archive_search(params = {}) ⇒ Struct
Stops an in-progress archive search job.
807 |
# File 'sig/client.rbs', line 807
def stop_archive_search: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags (keys and values) to a specified resource.
816 |
# File 'sig/client.rbs', line 816
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove one or more tags (keys and values) from a specified resource.
831 |
# File 'sig/client.rbs', line 831
def untag_resource: (
|
#update_archive(params = {}) ⇒ Struct
Updates the attributes of an existing email archive.
841 |
# File 'sig/client.rbs', line 841
def update_archive: (
|
#update_ingress_point(params = {}) ⇒ Struct
Update attributes of a provisioned ingress endpoint resource.
854 |
# File 'sig/client.rbs', line 854
def update_ingress_point: (
|
#update_relay(params = {}) ⇒ Struct
Updates the attributes of an existing relay resource.
869 |
# File 'sig/client.rbs', line 869
def update_relay: (
|
#update_rule_set(params = {}) ⇒ Struct
Update attributes of an already provisioned rule set.
886 |
# File 'sig/client.rbs', line 886
def update_rule_set: (
|
#update_traffic_policy(params = {}) ⇒ Struct
Update attributes of an already provisioned traffic policy resource.
899 |
# File 'sig/client.rbs', line 899
def update_traffic_policy: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4049 4050 4051 |
# File 'lib/aws-sdk-mailmanager/client.rb', line 4049 def waiter_names [] end |