Module: Aws::MailManager::Types

Defined in:
lib/aws-sdk-mailmanager/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AddHeaderAction, AddonInstance, AddonSubscription, AddressFilter, AddressList, Analysis, Archive, ArchiveAction, ArchiveBooleanExpression, ArchiveBooleanToEvaluate, ArchiveFilterCondition, ArchiveFilters, ArchiveRetention, ArchiveStringExpression, ArchiveStringToEvaluate, ConflictException, CreateAddonInstanceRequest, CreateAddonInstanceResponse, CreateAddonSubscriptionRequest, CreateAddonSubscriptionResponse, CreateAddressListImportJobRequest, CreateAddressListImportJobResponse, CreateAddressListRequest, CreateAddressListResponse, CreateArchiveRequest, CreateArchiveResponse, CreateIngressPointRequest, CreateIngressPointResponse, CreateRelayRequest, CreateRelayResponse, CreateRuleSetRequest, CreateRuleSetResponse, CreateTrafficPolicyRequest, CreateTrafficPolicyResponse, DeleteAddonInstanceRequest, DeleteAddonInstanceResponse, DeleteAddonSubscriptionRequest, DeleteAddonSubscriptionResponse, DeleteAddressListRequest, DeleteAddressListResponse, DeleteArchiveRequest, DeleteArchiveResponse, DeleteIngressPointRequest, DeleteIngressPointResponse, DeleteRelayRequest, DeleteRelayResponse, DeleteRuleSetRequest, DeleteRuleSetResponse, DeleteTrafficPolicyRequest, DeleteTrafficPolicyResponse, DeliverToMailboxAction, DeliverToQBusinessAction, DeregisterMemberFromAddressListRequest, DeregisterMemberFromAddressListResponse, DropAction, Envelope, ExportDestinationConfiguration, ExportStatus, ExportSummary, GetAddonInstanceRequest, GetAddonInstanceResponse, GetAddonSubscriptionRequest, GetAddonSubscriptionResponse, GetAddressListImportJobRequest, GetAddressListImportJobResponse, GetAddressListRequest, GetAddressListResponse, GetArchiveExportRequest, GetArchiveExportResponse, GetArchiveMessageContentRequest, GetArchiveMessageContentResponse, GetArchiveMessageRequest, GetArchiveMessageResponse, GetArchiveRequest, GetArchiveResponse, GetArchiveSearchRequest, GetArchiveSearchResponse, GetArchiveSearchResultsRequest, GetArchiveSearchResultsResponse, GetIngressPointRequest, GetIngressPointResponse, GetMemberOfAddressListRequest, GetMemberOfAddressListResponse, GetRelayRequest, GetRelayResponse, GetRuleSetRequest, GetRuleSetResponse, GetTrafficPolicyRequest, GetTrafficPolicyResponse, ImportDataFormat, ImportJob, IngressAnalysis, IngressBooleanExpression, IngressBooleanToEvaluate, IngressIpToEvaluate, IngressIpv4Expression, IngressIpv6Expression, IngressIpv6ToEvaluate, IngressIsInAddressList, IngressPoint, IngressPointAuthConfiguration, IngressPointConfiguration, IngressPointPasswordConfiguration, IngressStringExpression, IngressStringToEvaluate, IngressTlsProtocolExpression, IngressTlsProtocolToEvaluate, ListAddonInstancesRequest, ListAddonInstancesResponse, ListAddonSubscriptionsRequest, ListAddonSubscriptionsResponse, ListAddressListImportJobsRequest, ListAddressListImportJobsResponse, ListAddressListsRequest, ListAddressListsResponse, ListArchiveExportsRequest, ListArchiveExportsResponse, ListArchiveSearchesRequest, ListArchiveSearchesResponse, ListArchivesRequest, ListArchivesResponse, ListIngressPointsRequest, ListIngressPointsResponse, ListMembersOfAddressListRequest, ListMembersOfAddressListResponse, ListRelaysRequest, ListRelaysResponse, ListRuleSetsRequest, ListRuleSetsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTrafficPoliciesRequest, ListTrafficPoliciesResponse, MessageBody, Metadata, NetworkConfiguration, NoAuthentication, PolicyCondition, PolicyStatement, PrivateNetworkConfiguration, PublicNetworkConfiguration, RegisterMemberToAddressListRequest, RegisterMemberToAddressListResponse, Relay, RelayAction, RelayAuthentication, ReplaceRecipientAction, ResourceNotFoundException, Row, Rule, RuleAction, RuleBooleanExpression, RuleBooleanToEvaluate, RuleCondition, RuleDmarcExpression, RuleIpExpression, RuleIpToEvaluate, RuleIsInAddressList, RuleNumberExpression, RuleNumberToEvaluate, RuleSet, RuleStringExpression, RuleStringToEvaluate, RuleVerdictExpression, RuleVerdictToEvaluate, S3Action, S3ExportDestinationConfiguration, SavedAddress, SearchStatus, SearchSummary, SendAction, ServiceQuotaExceededException, SnsAction, StartAddressListImportJobRequest, StartAddressListImportJobResponse, StartArchiveExportRequest, StartArchiveExportResponse, StartArchiveSearchRequest, StartArchiveSearchResponse, StopAddressListImportJobRequest, StopAddressListImportJobResponse, StopArchiveExportRequest, StopArchiveExportResponse, StopArchiveSearchRequest, StopArchiveSearchResponse, Tag, TagResourceRequest, TagResourceResponse, ThrottlingException, TrafficPolicy, UntagResourceRequest, UntagResourceResponse, UpdateArchiveRequest, UpdateArchiveResponse, UpdateIngressPointRequest, UpdateIngressPointResponse, UpdateRelayRequest, UpdateRelayResponse, UpdateRuleSetRequest, UpdateRuleSetResponse, UpdateTrafficPolicyRequest, UpdateTrafficPolicyResponse, ValidationException

Instance Attribute Summary collapse

Instance Attribute Details

#add_headerTypes::AddHeaderAction

This action adds a header. This can be used to add arbitrary email headers.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#analysisTypes::Analysis

The Add On ARN and its returned value to evaluate in a verdict condition expression.

Returns:



2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
# File 'lib/aws-sdk-mailmanager/types.rb', line 2121

class IngressBooleanToEvaluate < Struct.new(
  :analysis,
  :is_in_address_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Analysis < IngressBooleanToEvaluate; end
  class IsInAddressList < IngressBooleanToEvaluate; end
  class Unknown < IngressBooleanToEvaluate; end
end

#archiveTypes::ArchiveAction

This action archives the email. This can be used to deliver an email to an archive.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#attributeString

The email verdict attribute to evaluate in a string verdict expression.

Returns:



270
271
272
273
274
275
276
277
278
279
# File 'lib/aws-sdk-mailmanager/types.rb', line 270

class ArchiveBooleanToEvaluate < Struct.new(
  :attribute,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Attribute < ArchiveBooleanToEvaluate; end
  class Unknown < ArchiveBooleanToEvaluate; end
end

#boolean_expressionTypes::RuleBooleanExpression

The condition applies to a boolean expression passed in this field.

Returns:



298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/aws-sdk-mailmanager/types.rb', line 298

class ArchiveFilterCondition < Struct.new(
  :string_expression,
  :boolean_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringExpression < ArchiveFilterCondition; end
  class BooleanExpression < ArchiveFilterCondition; end
  class Unknown < ArchiveFilterCondition; end
end

#deliver_to_mailboxTypes::DeliverToMailboxAction

This action delivers an email to a WorkMail mailbox.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#deliver_to_q_businessTypes::DeliverToQBusinessAction

This action delivers an email to an Amazon Q Business application for ingestion into its knowledge base.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#dmarc_expressionTypes::RuleDmarcExpression

The condition applies to a DMARC policy expression passed in this field.

Returns:



3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
# File 'lib/aws-sdk-mailmanager/types.rb', line 3724

class RuleCondition < Struct.new(
  :boolean_expression,
  :string_expression,
  :number_expression,
  :ip_expression,
  :verdict_expression,
  :dmarc_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class BooleanExpression < RuleCondition; end
  class StringExpression < RuleCondition; end
  class NumberExpression < RuleCondition; end
  class IpExpression < RuleCondition; end
  class VerdictExpression < RuleCondition; end
  class DmarcExpression < RuleCondition; end
  class Unknown < RuleCondition; end
end

#dropTypes::DropAction

This action terminates the evaluation of rules in the rule set.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#ip_expressionTypes::RuleIpExpression

The condition applies to an IP address expression passed in this field.

Returns:



3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
# File 'lib/aws-sdk-mailmanager/types.rb', line 3186

class PolicyCondition < Struct.new(
  :string_expression,
  :ip_expression,
  :ipv_6_expression,
  :tls_expression,
  :boolean_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringExpression < PolicyCondition; end
  class IpExpression < PolicyCondition; end
  class Ipv6Expression < PolicyCondition; end
  class TlsExpression < PolicyCondition; end
  class BooleanExpression < PolicyCondition; end
  class Unknown < PolicyCondition; end
end

#ipv_6_expressionTypes::IngressIpv6Expression

This represents an IPv6 based condition matching on the incoming mail. It performs the operation configured in ‘Operator’ and evaluates the ‘Protocol’ object against the ‘Value’.

Returns:



3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
# File 'lib/aws-sdk-mailmanager/types.rb', line 3186

class PolicyCondition < Struct.new(
  :string_expression,
  :ip_expression,
  :ipv_6_expression,
  :tls_expression,
  :boolean_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringExpression < PolicyCondition; end
  class IpExpression < PolicyCondition; end
  class Ipv6Expression < PolicyCondition; end
  class TlsExpression < PolicyCondition; end
  class BooleanExpression < PolicyCondition; end
  class Unknown < PolicyCondition; end
end

#is_in_address_listTypes::RuleIsInAddressList

The structure representing the address lists and address list attribute that will be used in evaluation of boolean expression.

Returns:



2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
# File 'lib/aws-sdk-mailmanager/types.rb', line 2121

class IngressBooleanToEvaluate < Struct.new(
  :analysis,
  :is_in_address_list,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Analysis < IngressBooleanToEvaluate; end
  class IsInAddressList < IngressBooleanToEvaluate; end
  class Unknown < IngressBooleanToEvaluate; end
end

#mime_header_attributeString

The email MIME X-Header attribute to evaluate in a string condition expression.

Returns:



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
# File 'lib/aws-sdk-mailmanager/types.rb', line 3972

class RuleStringToEvaluate < Struct.new(
  :attribute,
  :mime_header_attribute,
  :analysis,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Attribute < RuleStringToEvaluate; end
  class MimeHeaderAttribute < RuleStringToEvaluate; end
  class Analysis < RuleStringToEvaluate; end
  class Unknown < RuleStringToEvaluate; end
end

#no_authenticationTypes::NoAuthentication

Keep an empty structure if the relay destination server does not require SMTP credential authentication.

Returns:



3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
# File 'lib/aws-sdk-mailmanager/types.rb', line 3352

class RelayAuthentication < Struct.new(
  :secret_arn,
  :no_authentication,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class SecretArn < RelayAuthentication; end
  class NoAuthentication < RelayAuthentication; end
  class Unknown < RelayAuthentication; end
end

#number_expressionTypes::RuleNumberExpression

The condition applies to a number expression passed in this field.

Returns:



3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
# File 'lib/aws-sdk-mailmanager/types.rb', line 3724

class RuleCondition < Struct.new(
  :boolean_expression,
  :string_expression,
  :number_expression,
  :ip_expression,
  :verdict_expression,
  :dmarc_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class BooleanExpression < RuleCondition; end
  class StringExpression < RuleCondition; end
  class NumberExpression < RuleCondition; end
  class IpExpression < RuleCondition; end
  class VerdictExpression < RuleCondition; end
  class DmarcExpression < RuleCondition; end
  class Unknown < RuleCondition; end
end

#private_network_configurationTypes::PrivateNetworkConfiguration

Specifies the network configuration for the private ingress point.

Returns:



3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
# File 'lib/aws-sdk-mailmanager/types.rb', line 3125

class NetworkConfiguration < Struct.new(
  :public_network_configuration,
  :private_network_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class PublicNetworkConfiguration < NetworkConfiguration; end
  class PrivateNetworkConfiguration < NetworkConfiguration; end
  class Unknown < NetworkConfiguration; end
end

#public_network_configurationTypes::PublicNetworkConfiguration

Specifies the network configuration for the public ingress point.

Returns:



3125
3126
3127
3128
3129
3130
3131
3132
3133
3134
3135
3136
# File 'lib/aws-sdk-mailmanager/types.rb', line 3125

class NetworkConfiguration < Struct.new(
  :public_network_configuration,
  :private_network_configuration,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class PublicNetworkConfiguration < NetworkConfiguration; end
  class PrivateNetworkConfiguration < NetworkConfiguration; end
  class Unknown < NetworkConfiguration; end
end

#publish_to_snsTypes::SnsAction

This action publishes the email content to an Amazon SNS topic.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#relayTypes::RelayAction

This action relays the email to another SMTP server.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#replace_recipientTypes::ReplaceRecipientAction

The action replaces certain or all recipients with a different set of recipients.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#retention_periodString

The enum value sets the period for retaining emails in an archive.

Returns:



343
344
345
346
347
348
349
350
351
352
# File 'lib/aws-sdk-mailmanager/types.rb', line 343

class ArchiveRetention < Struct.new(
  :retention_period,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class RetentionPeriod < ArchiveRetention; end
  class Unknown < ArchiveRetention; end
end

#s3Types::S3ExportDestinationConfiguration

Configuration for delivering to an Amazon S3 bucket.

Returns:



1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/aws-sdk-mailmanager/types.rb', line 1148

class ExportDestinationConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < ExportDestinationConfiguration; end
  class Unknown < ExportDestinationConfiguration; end
end

#secret_arnString

The ARN of the secret created in secrets manager where the relay server’s SMTP credentials are stored.

Returns:



2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-mailmanager/types.rb', line 2326

class IngressPointConfiguration < Struct.new(
  :smtp_password,
  :secret_arn,
  :unknown)
  SENSITIVE = [:smtp_password]
  include Aws::Structure
  include Aws::Structure::Union

  class SmtpPassword < IngressPointConfiguration; end
  class SecretArn < IngressPointConfiguration; end
  class Unknown < IngressPointConfiguration; end
end

#sendTypes::SendAction

This action sends the email to the internet.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end

#smtp_passwordString

The password of the ingress endpoint resource.

Returns:



2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
# File 'lib/aws-sdk-mailmanager/types.rb', line 2326

class IngressPointConfiguration < Struct.new(
  :smtp_password,
  :secret_arn,
  :unknown)
  SENSITIVE = [:smtp_password]
  include Aws::Structure
  include Aws::Structure::Union

  class SmtpPassword < IngressPointConfiguration; end
  class SecretArn < IngressPointConfiguration; end
  class Unknown < IngressPointConfiguration; end
end

#string_expressionTypes::RuleStringExpression

The condition applies to a string expression passed in this field.

Returns:



298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/aws-sdk-mailmanager/types.rb', line 298

class ArchiveFilterCondition < Struct.new(
  :string_expression,
  :boolean_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringExpression < ArchiveFilterCondition; end
  class BooleanExpression < ArchiveFilterCondition; end
  class Unknown < ArchiveFilterCondition; end
end

#tls_expressionTypes::IngressTlsProtocolExpression

This represents a TLS based condition matching on the incoming mail. It performs the operation configured in ‘Operator’ and evaluates the ‘Protocol’ object against the ‘Value’.

Returns:



3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
# File 'lib/aws-sdk-mailmanager/types.rb', line 3186

class PolicyCondition < Struct.new(
  :string_expression,
  :ip_expression,
  :ipv_6_expression,
  :tls_expression,
  :boolean_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class StringExpression < PolicyCondition; end
  class IpExpression < PolicyCondition; end
  class Ipv6Expression < PolicyCondition; end
  class TlsExpression < PolicyCondition; end
  class BooleanExpression < PolicyCondition; end
  class Unknown < PolicyCondition; end
end

#verdict_expressionTypes::RuleVerdictExpression

The condition applies to a verdict expression passed in this field.

Returns:



3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
3741
3742
3743
# File 'lib/aws-sdk-mailmanager/types.rb', line 3724

class RuleCondition < Struct.new(
  :boolean_expression,
  :string_expression,
  :number_expression,
  :ip_expression,
  :verdict_expression,
  :dmarc_expression,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class BooleanExpression < RuleCondition; end
  class StringExpression < RuleCondition; end
  class NumberExpression < RuleCondition; end
  class IpExpression < RuleCondition; end
  class VerdictExpression < RuleCondition; end
  class DmarcExpression < RuleCondition; end
  class Unknown < RuleCondition; end
end

#write_to_s3Types::S3Action

This action writes the MIME content of the email to an S3 bucket.

Returns:



3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
3626
3627
3628
3629
# File 'lib/aws-sdk-mailmanager/types.rb', line 3602

class RuleAction < Struct.new(
  :drop,
  :relay,
  :archive,
  :write_to_s3,
  :send,
  :add_header,
  :replace_recipient,
  :deliver_to_mailbox,
  :deliver_to_q_business,
  :publish_to_sns,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Drop < RuleAction; end
  class Relay < RuleAction; end
  class Archive < RuleAction; end
  class WriteToS3 < RuleAction; end
  class Send < RuleAction; end
  class AddHeader < RuleAction; end
  class ReplaceRecipient < RuleAction; end
  class DeliverToMailbox < RuleAction; end
  class DeliverToQBusiness < RuleAction; end
  class PublishToSns < RuleAction; end
  class Unknown < RuleAction; end
end