Class: Aws::MailManager::Types::CreateAddressListRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::CreateAddressListRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_list_name ⇒ String
A user-friendly name for the address list.
-
#client_token ⇒ String
A unique token that Amazon SES uses to recognize subsequent retries of the same request.
-
#tags ⇒ Array<Types::Tag>
The tags used to organize, track, or control access for the resource.
Instance Attribute Details
#address_list_name ⇒ String
A user-friendly name for the address list.
619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 619 class CreateAddressListRequest < Struct.new( :client_token, :address_list_name, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique token that Amazon SES uses to recognize subsequent retries of the same request.
A suitable default value is auto-generated. You should normally not need to pass this option.
619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 619 class CreateAddressListRequest < Struct.new( :client_token, :address_list_name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags used to organize, track, or control access for the resource. For example, { "tags": "key2":"value2" }.
619 620 621 622 623 624 625 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 619 class CreateAddressListRequest < Struct.new( :client_token, :address_list_name, :tags) SENSITIVE = [] include Aws::Structure end |