Class: Aws::MailManager::Types::GetAddressListRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::GetAddressListRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_list_id ⇒ String
The identifier of an existing address list resource to be retrieved.
Instance Attribute Details
#address_list_id ⇒ String
The identifier of an existing address list resource to be retrieved.
1369 1370 1371 1372 1373 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1369 class GetAddressListRequest < Struct.new( :address_list_id) SENSITIVE = [] include Aws::Structure end |