Class: Aws::MailManager::Types::GetAddressListResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::GetAddressListResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_list_arn ⇒ String
The Amazon Resource Name (ARN) of the address list resource.
-
#address_list_id ⇒ String
The identifier of the address list resource.
-
#address_list_name ⇒ String
A user-friendly name for the address list resource.
-
#created_timestamp ⇒ Time
The date of when then address list was created.
-
#last_updated_timestamp ⇒ Time
The date of when the address list was last updated.
Instance Attribute Details
#address_list_arn ⇒ String
The Amazon Resource Name (ARN) of the address list resource.
1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1454 class GetAddressListResponse < Struct.new( :address_list_id, :address_list_arn, :address_list_name, :created_timestamp, :last_updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#address_list_id ⇒ String
The identifier of the address list resource.
1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1454 class GetAddressListResponse < Struct.new( :address_list_id, :address_list_arn, :address_list_name, :created_timestamp, :last_updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#address_list_name ⇒ String
A user-friendly name for the address list resource.
1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1454 class GetAddressListResponse < Struct.new( :address_list_id, :address_list_arn, :address_list_name, :created_timestamp, :last_updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#created_timestamp ⇒ Time
The date of when then address list was created.
1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1454 class GetAddressListResponse < Struct.new( :address_list_id, :address_list_arn, :address_list_name, :created_timestamp, :last_updated_timestamp) SENSITIVE = [] include Aws::Structure end |
#last_updated_timestamp ⇒ Time
The date of when the address list was last updated.
1454 1455 1456 1457 1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1454 class GetAddressListResponse < Struct.new( :address_list_id, :address_list_arn, :address_list_name, :created_timestamp, :last_updated_timestamp) SENSITIVE = [] include Aws::Structure end |