Class: Aws::MailManager::Types::GetArchiveExportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::GetArchiveExportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
The response containing details of the specified archive export job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#archive_id ⇒ String
The identifier of the archive the email export was performed from.
-
#export_destination_configuration ⇒ Types::ExportDestinationConfiguration
Where the exported emails are being delivered.
-
#filters ⇒ Types::ArchiveFilters
The criteria used to filter emails included in the export.
-
#from_timestamp ⇒ Time
The start of the timestamp range the exported emails cover.
-
#max_results ⇒ Integer
The maximum number of email items included in the export.
-
#status ⇒ Types::ExportStatus
The current status of the export job.
-
#to_timestamp ⇒ Time
The end of the date range the exported emails cover.
Instance Attribute Details
#archive_id ⇒ String
The identifier of the archive the email export was performed from.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |
#export_destination_configuration ⇒ Types::ExportDestinationConfiguration
Where the exported emails are being delivered.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Types::ArchiveFilters
The criteria used to filter emails included in the export.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |
#from_timestamp ⇒ Time
The start of the timestamp range the exported emails cover.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of email items included in the export.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::ExportStatus
The current status of the export job.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |
#to_timestamp ⇒ Time
The end of the date range the exported emails cover.
1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 1510 class GetArchiveExportResponse < Struct.new( :archive_id, :filters, :from_timestamp, :to_timestamp, :max_results, :export_destination_configuration, :status) SENSITIVE = [] include Aws::Structure end |