Class: Aws::MailManager::Types::ImportJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::ImportJob
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Details about an import job.
Constant Summary collapse
- SENSITIVE =
[:pre_signed_url]
Instance Attribute Summary collapse
-
#address_list_id ⇒ String
The unique identifier of the address list the import job was created for.
-
#completed_timestamp ⇒ Time
The timestamp of when the import job was completed.
-
#created_timestamp ⇒ Time
The timestamp of when the import job was created.
-
#error ⇒ String
The reason for failure of an import job.
-
#failed_items_count ⇒ Integer
The number of addresses in the input that failed to get imported into address list.
-
#import_data_format ⇒ Types::ImportDataFormat
The format of the input for the import job.
-
#imported_items_count ⇒ Integer
The number of addresses in the input that were successfully imported into the address list.
-
#job_id ⇒ String
The identifier of the import job.
-
#name ⇒ String
A user-friendly name for the import job.
-
#pre_signed_url ⇒ String
The pre-signed URL target for uploading the input file.
-
#start_timestamp ⇒ Time
The timestamp of when the import job was started.
-
#status ⇒ String
The status of the import job.
Instance Attribute Details
#address_list_id ⇒ String
The unique identifier of the address list the import job was created for.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#completed_timestamp ⇒ Time
The timestamp of when the import job was completed.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#created_timestamp ⇒ Time
The timestamp of when the import job was created.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#error ⇒ String
The reason for failure of an import job.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#failed_items_count ⇒ Integer
The number of addresses in the input that failed to get imported into address list.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#import_data_format ⇒ Types::ImportDataFormat
The format of the input for the import job.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#imported_items_count ⇒ Integer
The number of addresses in the input that were successfully imported into the address list.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#job_id ⇒ String
The identifier of the import job.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#name ⇒ String
A user-friendly name for the import job.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#pre_signed_url ⇒ String
The pre-signed URL target for uploading the input file.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#start_timestamp ⇒ Time
The timestamp of when the import job was started.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#status ⇒ String
The status of the import job.
2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2114 class ImportJob < Struct.new( :job_id, :name, :status, :pre_signed_url, :imported_items_count, :failed_items_count, :import_data_format, :address_list_id, :created_timestamp, :start_timestamp, :completed_timestamp, :error) SENSITIVE = [:pre_signed_url] include Aws::Structure end |