Class: Aws::MailManager::Types::ListMembersOfAddressListResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::ListMembersOfAddressListResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#addresses ⇒ Array<Types::SavedAddress>
The list of addresses.
-
#next_token ⇒ String
If NextToken is returned, there are more results available.
Instance Attribute Details
#addresses ⇒ Array<Types::SavedAddress>
The list of addresses.
2851 2852 2853 2854 2855 2856 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2851 class ListMembersOfAddressListResponse < Struct.new( :addresses, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If NextToken is returned, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.
2851 2852 2853 2854 2855 2856 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2851 class ListMembersOfAddressListResponse < Struct.new( :addresses, :next_token) SENSITIVE = [] include Aws::Structure end |