Class: Aws::MailManager::Types::ListRelaysRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.

Returns:



2994
2995
2996
2997
2998
2999
# File 'lib/aws-sdk-mailmanager/types.rb', line 2994

class ListRelaysRequest < Struct.new(
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The number of relays to be returned in one request.

Returns:



2994
2995
2996
2997
2998
2999
# File 'lib/aws-sdk-mailmanager/types.rb', line 2994

class ListRelaysRequest < Struct.new(
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end