Class: Aws::MailManager::Types::ListRelaysResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If NextToken is returned, there are more results available. The value of NextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.



2889
2890
2891
2892
2893
2894
# File 'lib/aws-sdk-mailmanager/types.rb', line 2889

class ListRelaysResponse < Struct.new(
  :relays,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#relaysArray<Types::Relay>

The list of returned relays.



2889
2890
2891
2892
2893
2894
# File 'lib/aws-sdk-mailmanager/types.rb', line 2889

class ListRelaysResponse < Struct.new(
  :relays,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end