Class: Aws::MailManager::Types::ListRuleSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::ListRuleSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.
-
#page_size ⇒ Integer
The maximum number of rule set resources that are returned per call.
Instance Attribute Details
#next_token ⇒ String
If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.
3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 3033 class ListRuleSetsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The maximum number of rule set resources that are returned per call. You can use NextToken to obtain further rule sets.
3033 3034 3035 3036 3037 3038 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 3033 class ListRuleSetsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |