Class: Aws::MailManager::Types::ListTrafficPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.

Returns:

  • (String)


3099
3100
3101
3102
3103
3104
# File 'lib/aws-sdk-mailmanager/types.rb', line 3099

class ListTrafficPoliciesRequest < Struct.new(
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The maximum number of traffic policy resources that are returned per call. You can use NextToken to obtain further traffic policies.

Returns:

  • (Integer)


3099
3100
3101
3102
3103
3104
# File 'lib/aws-sdk-mailmanager/types.rb', line 3099

class ListTrafficPoliciesRequest < Struct.new(
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end