Class: Aws::MailManager::Types::Metadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

The metadata about the email.

Constant Summary collapse

SENSITIVE =
[:sender_ip_address]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_setString

The name of the configuration set used when sent through a configuration set with archiving enabled.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#ingress_point_idString

The ID of the ingress endpoint through which the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#rule_set_idString

The ID of the rule set that processed the email.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#sender_hostnameString

The name of the host from which the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#sender_ip_addressString

The IP address of the host from which the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#sending_methodString

The name of the API call used when sent through a configuration set with archiving enabled.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#sending_poolString

The name of the dedicated IP pool used when sent through a configuration set with archiving enabled.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#source_arnString

Specifies the archived email source, identified by either a Rule Set’s ARN with an Archive action, or a Configuration Set’s Archive ARN.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#source_identityString

The identity name used to authorize the sending action when sent through a configuration set with archiving enabled.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#timestampTime

The timestamp of when the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#tls_cipher_suiteString

The TLS cipher suite used to communicate with the host from which the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#tls_protocolString

The TLS protocol used to communicate with the host from which the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end

#traffic_policy_idString

The ID of the traffic policy that was in effect when the email was received.



3090
3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
# File 'lib/aws-sdk-mailmanager/types.rb', line 3090

class  < Struct.new(
  :timestamp,
  :ingress_point_id,
  :traffic_policy_id,
  :rule_set_id,
  :sender_hostname,
  :sender_ip_address,
  :tls_cipher_suite,
  :tls_protocol,
  :sending_method,
  :source_identity,
  :sending_pool,
  :configuration_set,
  :source_arn)
  SENSITIVE = [:sender_ip_address]
  include Aws::Structure
end