Class: Aws::MailManager::Types::StartArchiveExportRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

The request to initiate an export of emails from an archive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#archive_idString

The identifier of the archive to export emails from.

Returns:

  • (String)


4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#export_destination_configurationTypes::ExportDestinationConfiguration

Details on where to deliver the exported email data.



4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#filtersTypes::ArchiveFilters

Criteria to filter which emails are included in the export.



4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#from_timestampTime

The start of the timestamp range to include emails from.

Returns:

  • (Time)


4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#include_metadataBoolean

Whether to include message metadata as JSON files in the export.

Returns:

  • (Boolean)


4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of email items to include in the export.

Returns:

  • (Integer)


4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#to_timestampTime

The end of the timestamp range to include emails from.

Returns:

  • (Time)


4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
4452
# File 'lib/aws-sdk-mailmanager/types.rb', line 4442

class StartArchiveExportRequest < Struct.new(
  :archive_id,
  :filters,
  :from_timestamp,
  :to_timestamp,
  :max_results,
  :export_destination_configuration,
  :include_metadata)
  SENSITIVE = []
  include Aws::Structure
end