Class: Aws::MailManager::Types::TrustStore
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::TrustStore
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
The trust store used for mutual TLS authentication. It contains the certificate authority (CA) certificates and optional certificate revocation list (CRL).
Constant Summary collapse
- SENSITIVE =
[:ca_content, :crl_content]
Instance Attribute Summary collapse
-
#ca_content ⇒ String
The PEM-encoded certificate authority (CA) certificates bundle for the trust store.
-
#crl_content ⇒ String
The PEM-encoded certificate revocation lists (CRLs) for the trust store.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the trust store contents.
Instance Attribute Details
#ca_content ⇒ String
The PEM-encoded certificate authority (CA) certificates bundle for the trust store.
4700 4701 4702 4703 4704 4705 4706 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 4700 class TrustStore < Struct.new( :ca_content, :crl_content, :kms_key_arn) SENSITIVE = [:ca_content, :crl_content] include Aws::Structure end |
#crl_content ⇒ String
The PEM-encoded certificate revocation lists (CRLs) for the trust store. There can be one CRL per certificate authority (CA) in the trust store.
4700 4701 4702 4703 4704 4705 4706 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 4700 class TrustStore < Struct.new( :ca_content, :crl_content, :kms_key_arn) SENSITIVE = [:ca_content, :crl_content] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key used to encrypt the trust store contents.
4700 4701 4702 4703 4704 4705 4706 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 4700 class TrustStore < Struct.new( :ca_content, :crl_content, :kms_key_arn) SENSITIVE = [:ca_content, :crl_content] include Aws::Structure end |