Class: Aws::MailManager::Types::GetAddressListResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#address_list_arnString

The Amazon Resource Name (ARN) of the address list resource.



1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-mailmanager/types.rb', line 1397

class GetAddressListResponse < Struct.new(
  :address_list_id,
  :address_list_arn,
  :address_list_name,
  :created_timestamp,
  :last_updated_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#address_list_idString

The identifier of the address list resource.



1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-mailmanager/types.rb', line 1397

class GetAddressListResponse < Struct.new(
  :address_list_id,
  :address_list_arn,
  :address_list_name,
  :created_timestamp,
  :last_updated_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#address_list_nameString

A user-friendly name for the address list resource.



1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-mailmanager/types.rb', line 1397

class GetAddressListResponse < Struct.new(
  :address_list_id,
  :address_list_arn,
  :address_list_name,
  :created_timestamp,
  :last_updated_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#created_timestampTime

The date of when then address list was created.



1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-mailmanager/types.rb', line 1397

class GetAddressListResponse < Struct.new(
  :address_list_id,
  :address_list_arn,
  :address_list_name,
  :created_timestamp,
  :last_updated_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timestampTime

The date of when the address list was last updated.



1397
1398
1399
1400
1401
1402
1403
1404
1405
# File 'lib/aws-sdk-mailmanager/types.rb', line 1397

class GetAddressListResponse < Struct.new(
  :address_list_id,
  :address_list_arn,
  :address_list_name,
  :created_timestamp,
  :last_updated_timestamp)
  SENSITIVE = []
  include Aws::Structure
end