Class: Aws::MailManager::Types::ListMembersOfAddressListRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::ListMembersOfAddressListRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#address_list_id ⇒ String
The unique identifier of the address list to list the addresses from.
-
#filter ⇒ Types::AddressFilter
Filter to be used to limit the results.
-
#next_token ⇒ String
If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.
-
#page_size ⇒ Integer
The maximum number of address list members that are returned per call.
Instance Attribute Details
#address_list_id ⇒ String
The unique identifier of the address list to list the addresses from.
2830 2831 2832 2833 2834 2835 2836 2837 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2830 class ListMembersOfAddressListRequest < Struct.new( :address_list_id, :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::AddressFilter
Filter to be used to limit the results.
2830 2831 2832 2833 2834 2835 2836 2837 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2830 class ListMembersOfAddressListRequest < Struct.new( :address_list_id, :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.
2830 2831 2832 2833 2834 2835 2836 2837 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2830 class ListMembersOfAddressListRequest < Struct.new( :address_list_id, :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The maximum number of address list members that are returned per call. You can use NextToken to retrieve the next page of members.
2830 2831 2832 2833 2834 2835 2836 2837 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2830 class ListMembersOfAddressListRequest < Struct.new( :address_list_id, :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |