Class: Aws::MailManager::Types::ListRuleSetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mailmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.

Returns:

  • (String)


2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-mailmanager/types.rb', line 2909

class ListRuleSetsRequest < Struct.new(
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The maximum number of rule set resources that are returned per call. You can use NextToken to obtain further rule sets.

Returns:

  • (Integer)


2909
2910
2911
2912
2913
2914
# File 'lib/aws-sdk-mailmanager/types.rb', line 2909

class ListRuleSetsRequest < Struct.new(
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end