Class: Aws::MailManager::Types::ListTrafficPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MailManager::Types::ListTrafficPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mailmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.
-
#page_size ⇒ Integer
The maximum number of traffic policy resources that are returned per call.
Instance Attribute Details
#next_token ⇒ String
If you received a pagination token from a previous call to this API, you can provide it here to continue paginating through the next page of results.
2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2975 class ListTrafficPoliciesRequest < Struct.new( :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The maximum number of traffic policy resources that are returned per call. You can use NextToken to obtain further traffic policies.
2975 2976 2977 2978 2979 2980 |
# File 'lib/aws-sdk-mailmanager/types.rb', line 2975 class ListTrafficPoliciesRequest < Struct.new( :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |